package com.yidian.shenghuoquan.commodity.ui.coupon

import android.webkit.WebChromeClient
import android.webkit.WebView
import androidx.activity.viewModels
import com.orhanobut.hawk.Hawk
import com.yidian.common.HawkConfig
import com.yidian.common.XRouterPathConstants
import com.yidian.common.extensions.initTitleBar
import com.yidian.common.mvvm.BaseMvvmActivity
import com.yidian.common.utils.DialogUtils
import com.yidian.shenghuoquan.commodity.R
import com.yidian.shenghuoquan.commodity.databinding.CommodityActivityPublishCouponsBinding
import com.yidian.xarc.xbrid.XBridManager
import com.yidian.xarc.xbrid.XWebView
import com.yidian.xpage.XPageViewProtocol
import timber.log.Timber

/**
 * 发布优惠券
 */
class PublishCouponsActivity : BaseMvvmActivity<CommodityActivityPublishCouponsBinding, PublishCouponsViewModel>(), XPageViewProtocol {

  private lateinit var webView: XWebView

  override val layoutId: Int = R.layout.commodity_activity_publish_coupons

  override val vm: PublishCouponsViewModel by viewModels()

  override fun getXPageName(): String {
    return XRouterPathConstants.PUBLISH_COUPONS_ACTIVITY
  }

  override fun initView() {
    initTitleBar(binding.include.toolbar, binding.include.tvTitle, "发布优惠券")
    val serializableExtra = intent.getSerializableExtra(XRouterPathConstants.ParamsKey)
    if (serializableExtra == null) {
      initWebView()
    } else {
      val paramsMap = serializableExtra as HashMap<*, *>
      val couponId = paramsMap[CouponId] as String
      initWebView(couponId)
    }
  }

  private fun initWebView(couponId: String = "") {
    webView = XBridManager.getWebView(this, "testidenfier", binding.couponWebView)
    val lifeAccountId = Hawk.get(HawkConfig.LifeAccountId, "")
    val webUrl = if (couponId.isNotBlank()) {
      "?coupon_id=$couponId&life_account_id=$lifeAccountId"
    } else {
      "?life_account_id=$lifeAccountId"
    }
    webView.loadUrl("xbrid_coupon_publish$webUrl")
    Timber.e("请求地址：  xbrid_coupon_publish$webUrl")
    webView.webChromeClient = object : WebChromeClient() {
      override fun onProgressChanged(view: WebView?, newProgress: Int) {
        super.onProgressChanged(view, newProgress)
        if (newProgress == 100) {
          Timber.e("发布优惠券页面加载完成")
        }
      }
    }
    WebView.setWebContentsDebuggingEnabled(true)
  }

  override fun onDestroy() {
    super.onDestroy()
    if (::webView.isInitialized) {
      XBridManager.backWebView(webView)
    }
  }

  override fun onBackPressed() {
    DialogUtils.showConfirmDialog(this, "返回后商品将不保存？")
  }

  companion object {
    const val CouponId = "coupon_id"
  }

}
